@@ -2,22 +2,24 @@ import os
 import sys
 sys.path.insert(0, os.getcwd())
 
+import pytest
 import numpy as np
 import pandas as pd
 import dreamtools as dt
 
 
 @np.vectorize
-def approximately_equal(x, y, ndigits=0):
+def approximately_equal(x, y, ndigits=6):
   return round(x, ndigits) == round(y, ndigits)
 
 def test_gdx_read():
   db = dt.Gdx("test.gdx")
-  assert approximately_equal(db["qY"]["byg", 2025], 257.55)
-  assert approximately_equal(db["qI_s"]["IB", "fre", 2025], 7.41)
+  assert approximately_equal(db["qY"]["byg", 2025], 257.55, ndigits=2)
+  assert approximately_equal(db["qI_s"]["IB", "fre", 2025], 7.41, ndigits=2)
   assert approximately_equal(db["eHh"], 1.25)
   assert db["fp"] == 1.0178
-  assert all(approximately_equal(db["inf_factor"], db["fp"]**(2010 - db["inf_factor"].index)))
+  db.create_parameter("inf_factor_test", db["t"], data=db["fp"]**(2010 - db["t"]))
+  assert all(approximately_equal(db["inf_factor"], db["inf_factor_test"]))
   assert db["s"].name == "s_"
   assert db.vHh.loc["NetFin","tot",1970] == 0
   assert set(db["vHh"].index.get_level_values("a_")).issubset(set(db["a_"]))
@@ -164,7 +166,7 @@ def test_multiply_with_different_sets():
   db = dt.Gdx("test.gdx")
   i, s = db["i"], db["s"]
   result = (db["pI"] * db["qI_s"].loc[i, s]).groupby("t").sum() / db["vI"]["iTot"] # Using pI_s would give exact 1
-  assert all(approximately_equal(result.loc[2030:], 1))
+  assert all(approximately_equal(result.loc[2030:], 1, ndigits=1))
 
 def test_export_with_no_changes():
   dt.Gdx("test.gdx").export("test_export.gdx", relative_path=True)
@@ -240,6 +242,7 @@ def test_create_methods():
   t = Set("t", range(2000, 2021), "Årstal")
   s = Set("s", ["tjenester", "fremstilling"], "Brancher", ["Tjenester", "Fremstilling"])
   st = Set("st", [s, t], "Branche x år dummy")
+
   sub = Set("sub", ["tjenester"], "Subset af brancher", domains=["s"])
 
   one2one = Set("one2one", [(2010, 2015), (2011, 2016)], "1 til 1 mapping", domains=["t", "t"])
@@ -263,6 +266,9 @@ def test_create_methods():
   assert pd.isna(d["tjenester",2010])
   assert pd.isna(y["tjenester",2010])
 
+  # Test that created symbols can be exported
+  db.export("test_export.gdx")
+
 def test_import_export_empty():
   # Create empty GamsPandasDatabase and alias creation methods
   db = dt.GamsPandasDatabase()
@@ -279,8 +285,10 @@ def test_import_export_empty():
   db.export("test_export.gdx")
   db = dt.Gdx("test_export.gdx")
 
-  db.p.loc[t, s] = 1
-  db.v.loc[t, s] = 1
+  for i in s:
+    for j in t:
+      db.p.loc[i, j] = 1
+      db.v.loc[i, j] = 1
   db.export("test_export.gdx")
   db = dt.Gdx("test_export.gdx")
 
@@ -294,3 +302,24 @@ def test_get_sparse():
   assert len(dense["qY"]) == len(pd.MultiIndex.from_product(db.get("s_", "t")))
   assert len(dense["pBolig"]) == len(db["t"])
 
+def test_time_index_pos():
+  db = dt.Gdx("test.gdx")
+  p = db.create_parameter("p", [db.s_, db.s, db.t], data=0)
+  p_inv_sets = db.create_parameter("p_inv_sets", [db.t, db.s, db.s_], data=0)
+  assert dt.DataFrame(p[:,'tje',:]).size == dt.DataFrame(p_inv_sets[:,'tje',:]).size
+
+def test_aggregation_with_2_sets():
+  db = dt.Gdx("test.gdx")
+  p = db.create_parameter("p", [db.a_, db.portf_, db.t], data=0)
+  assert dt.DataFrame(p).columns[0] == "p[tot,NetFin]"
+
+def test_compare():
+  db = dt.Gdx("test.gdx")
+  with pytest.raises(ValueError):
+    dt.DataFrame(db.qBNP, "q")
+  baseline = dt.REFERENCE_DATABASE = dt.Gdx("test.gdx")
+  db.qBNP *= 1.01
+  q = dt.DataFrame(db.qBNP, "q", start_year=2025)
+  m = dt.DataFrame(db.qBNP, "m", start_year=2025)
+  assert approximately_equal(q, 0.01).all().all()
+  assert ((15 < m) & (m < 25)).all().all()
