@@ -1,6 +1,6 @@
-PLOTLY = True
 try:
   import plotly
+  PLOTLY = True
 except ImportError:
   PLOTLY = False
 
@@ -8,7 +8,6 @@ if PLOTLY:
   import pandas
   pandas.options.plotting.backend = "plotly"
   from .timeseries_analysis import *
-  from .plotly_util import *
   from .reporting import *
   from .age_plot import *
 
@@ -17,5 +16,4 @@ if PLOTLY:
   pio.templates["dream"] = dream_template
   pio.templates.default = "dream"
 
-  import dreamtools as dt
-  pio.orca.config.default_scale = dt.PLOT_SCALE
+  from .dream_plotly_template import dream_colors_rgb, small_figure_layout, large_figure_layout
